@@ -29,7 +29,7 @@ def execute_copy(args):
 
 
 def transpile_copy(
-        widget_state_container
+        steps_manager
     ):
     """
     This always returns nothing; we are just making copies
