@@ -32,7 +32,7 @@ class MitoWidgetTestWrapper:
     def transpiled_code(self):
         # NOTE: we don't add comments to this testing functionality, so that 
         # we don't have to change tests if we update comments
-        return transpile(self.mito_widget.widget_state_container, add_comments=False)['code']
+        return transpile(self.mito_widget.steps_manager, add_comments=False)['code']
 
     def add_column(self, sheet_index: int, column_header: str, column_header_index=-1):
         """
@@ -44,9 +44,11 @@ class MitoWidgetTestWrapper:
             'id': get_new_id(),
             'type': 'add_column_edit',
             'step_id': get_new_id(),
-            'sheet_index': sheet_index,
-            'column_header': column_header,
-            'column_header_index': column_header_index
+            'params': {
+                'sheet_index': sheet_index,
+                'column_header': column_header,
+                'column_header_index': column_header_index
+            }
         })
     
     def set_formula(
@@ -70,9 +72,11 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'set_column_formula_edit',
                 'step_id': get_new_id(),
-                'sheet_index': sheet_index,
-                'column_header': column_header,
-                'new_formula': formula,
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_header': column_header,
+                    'new_formula': formula,
+                }
             }
         )
 
@@ -92,12 +96,14 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'merge_edit',
                 'step_id': get_new_id(),
-                'sheet_index_one': sheet_index_one,
-                'merge_key_one': merge_key_one,
-                'selected_columns_one': selected_columns_one,
-                'sheet_index_two': sheet_index_two,
-                'merge_key_two': merge_key_two,
-                'selected_columns_two': selected_columns_two
+                'params': {
+                    'sheet_index_one': sheet_index_one,
+                    'merge_key_one': merge_key_one,
+                    'selected_columns_one': selected_columns_one,
+                    'sheet_index_two': sheet_index_two,
+                    'merge_key_two': merge_key_two,
+                    'selected_columns_two': selected_columns_two
+                }
             }
         )
 
@@ -106,7 +112,9 @@ class MitoWidgetTestWrapper:
             sheet_index, 
             pivot_rows,
             pivot_columns,
-            values
+            values,
+            destination_sheet_index=None,
+            step_id=None
         ):
         self.mito_widget.receive_message(
             self.mito_widget,
@@ -114,11 +122,14 @@ class MitoWidgetTestWrapper:
                 'event': 'edit_event',
                 'id': get_new_id(),
                 'type': 'pivot_edit',
-                'step_id': get_new_id(),
-                'sheet_index': sheet_index,
-                'pivot_rows': pivot_rows,
-                'pivot_columns': pivot_columns,
-                'values': values
+                'step_id': get_new_id() if step_id is None else step_id,
+                'params': {
+                    'sheet_index': sheet_index,
+                    'pivot_rows': pivot_rows,
+                    'pivot_columns': pivot_columns,
+                    'values': values,
+                    'destination_sheet_index': destination_sheet_index
+                }
             }
         )
 
@@ -138,14 +149,16 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'filter_column_edit',
                 'step_id': get_new_id(),
-                'sheet_index': sheet_index,
-                'column_header': column,
-                'operator': operator,
-                'filters': [{
-                    'type': type_,
-                    'condition': condition,
-                    'value': value
-                }]
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_header': column,
+                    'operator': operator,
+                    'filters': [{
+                        'type': type_,
+                        'condition': condition,
+                        'value': value
+                    }]
+                }
             }
         )
     
@@ -163,10 +176,12 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'filter_column_edit',
                 'step_id': get_new_id(),
-                'sheet_index': sheet_index,
-                'column_header': column,
-                'operator': operator,
-                'filters': filters
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_header': column,
+                    'operator': operator,
+                    'filters': filters
+                }
             }
         )
     
@@ -183,9 +198,11 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'sort_edit',
                 'step_id': get_new_id(),
-                'sheet_index': sheet_index,
-                'column_header': column,
-                'sort_direction': sort_direction
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_header': column,
+                    'sort_direction': sort_direction
+                }
             }
         )
 
@@ -202,9 +219,11 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'reorder_column_edit',
                 'step_id': get_new_id(),
-                'sheet_index': sheet_index,
-                'column_header': column_header,
-                'new_column_index': new_column_index
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_header': column_header,
+                    'new_column_index': new_column_index
+                }
             }
         )
 
@@ -216,9 +235,11 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'rename_column_edit',
                 'step_id': get_new_id(),
-                'sheet_index': sheet_index,
-                'old_column_header': old_column_header,
-                'new_column_header': new_column_header
+                'params': {
+                    'sheet_index': sheet_index,
+                    'old_column_header': old_column_header,
+                    'new_column_header': new_column_header
+                }
             }
         )
 
@@ -230,8 +251,10 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'delete_column_edit',
                 'step_id': get_new_id(),
-                'sheet_index': sheet_index,
-                'column_header': column_header
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_header': column_header
+                }
             }
         )
 
@@ -243,9 +266,11 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'change_column_dtype_edit',
                 'step_id': get_new_id(),
-                'sheet_index': sheet_index,
-                'column_header': column_header,
-                'new_dtype': new_dtype
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_header': column_header,
+                    'new_dtype': new_dtype
+                }
             }
         )
 
@@ -257,22 +282,12 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'simple_import_edit',
                 'step_id': get_new_id(),
-                'file_names': file_names
+                'params': {
+                    'file_names': file_names
+                }
             }
         )
 
-    def raw_python_import(self, python_code: str, df_names: List[str]):
-        self.mito_widget.receive_message(
-            self.mito_widget,
-            {
-                'event': 'edit_event',
-                'id': get_new_id(),
-                'type': 'raw_python_import_edit',
-                'step_id': get_new_id(),
-                'python_code': python_code,
-                'new_df_names': df_names
-            }
-        )
     
     def undo(self):
         self.mito_widget.receive_message(
@@ -328,7 +343,9 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'dataframe_delete_edit',
                 'step_id': get_new_id(),
-                'sheet_index': sheet_index
+                'params': {
+                    'sheet_index': sheet_index
+                }
             }
         )
 
@@ -340,7 +357,9 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'dataframe_duplicate_edit',
                 'step_id': get_new_id(),
-                'sheet_index': sheet_index,
+                'params': {
+                    'sheet_index': sheet_index,
+                }
             }
         )
 
@@ -352,8 +371,10 @@ class MitoWidgetTestWrapper:
                 'id': get_new_id(),
                 'type': 'dataframe_rename_edit',
                 'step_id': get_new_id(),
-                'sheet_index': sheet_index,
-                'new_dataframe_name': new_dataframe_name
+                'params': {
+                    'sheet_index': sheet_index,
+                    'new_dataframe_name': new_dataframe_name
+                }
             }
         )
 
@@ -397,7 +418,7 @@ class MitoWidgetTestWrapper:
 
         Errors if the value does not exist
         """
-        return self.mito_widget.widget_state_container.dfs[sheet_index].at[row - 1, column_header]
+        return self.mito_widget.steps_manager.curr_step.dfs[sheet_index].at[row - 1, column_header]
 
     def get_column(self, sheet_index: int, column_header: str, as_list: bool):
         """
@@ -407,8 +428,8 @@ class MitoWidgetTestWrapper:
         Errors if the column does not exist. 
         """
         if as_list:
-            return self.mito_widget.widget_state_container.dfs[sheet_index][column_header].tolist()
-        return self.mito_widget.widget_state_container.dfs[sheet_index][column_header]
+            return self.mito_widget.steps_manager.dfs[sheet_index][column_header].tolist()
+        return self.mito_widget.steps_manager.dfs[sheet_index][column_header]
 
 def create_mito_wrapper(sheet_one_A_data, sheet_two_A_data=None) -> MitoWidgetTestWrapper:
     """
