@@ -17,7 +17,7 @@ APPEND_USER_FIELD_EVENT = 'append_user_field_update'
 APPEND_USER_FIELD_PARAMS = ['field', 'value']
 
 
-def execute_append_user_field_update(wsc, field, value):
+def execute_append_user_field_update(steps_manager, field, value):
     """
     The function responsible for appending value to the list
     stored at field
